from llama_index import Document
from llama_index.query_engine import BaseQueryEngine

from autollm.auto.query_engine import AutoQueryEngine


def test_auto_query_engine_from_parameters():
    documents = [Document.example()]
    vector_store_params = {"vector_store_type": "SimpleVectorStore"}
    query_engine = AutoQueryEngine.from_parameters(
        documents=documents, vector_store_params=vector_store_params)

    # Check if the query_engine is an instance of BaseQueryEngine
    assert isinstance(query_engine, BaseQueryEngine)



import logging

from llama_index.prompts import ChatMessage, ChatPromptTemplate, MessageRole

from autollm.utils.templates import QUERY_PROMPT_TEMPLATE, SYSTEM_PROMPT

logger = logging.getLogger(__name__)


def set_default_prompt_template() -> ChatPromptTemplate:
    """
    Sets the default prompt template for the query engine.

    Returns:
        SystemPrompt (str): The default system prompt for the query engine.
        ChatPromptTemplate: The default prompt template for the query engine.
    """
    chat_text_msgs = [
        ChatMessage(
            role=MessageRole.USER,
            content=QUERY_PROMPT_TEMPLATE,
        ),
    ]

    return SYSTEM_PROMPT, ChatPromptTemplate(chat_text_msgs)
